@@ -222,8 +222,9 @@ class client:
                 await send_message("enemyu," + self.client_instance.player.get_sent_to_enemies())
             elif Response.split(',')[0] == "diceroll":
                 roll = [int(x) for x in Response.split(',')[1:]]
+                self.client_instance.counter=0
                 self.client_instance.is_rolling = True
-                time.sleep(.5)
+                time.sleep(random.uniform(.5, 1.5))
                 self.client_instance.is_rolling = False
                 if sum(roll) in [8,11]:
                     self.client_instance.add_text('An '+ str(sum(roll)) + ' was rolled.')
@@ -607,8 +608,8 @@ def main():
                 cli, url, game_code, player_code, lobby_obj.name, lobby_obj.color, lobby_obj.screen_num, lobby_obj,
                 lobby_obj.is_host)).start()
         except RuntimeError:
-            #pass
-            print('thread\'s dead , baby, thread is dead')
+            pass
+            #print('thread\'s dead , baby, thread is dead')
         return 'success'
 
     def leave_lobby(lobby_obj):
@@ -631,13 +632,9 @@ def main():
         player_code = response[1]
         color = response[2]
         screen_num = response[3]
-    try:
-        test = GameLobby(RESOLUTION, callbacks=[create_game, join_game, leave_lobby, start])
-    except TypeError as a:
-        try:
-            test.to_menu=True
-        except UnboundLocalError:
-            print(a)
+    test = GameLobby(RESOLUTION, callbacks=[create_game, join_game, leave_lobby, start])
+        #test.to_menu=True
+
 
 if __name__ == "__main__":
     main()
