@@ -65,7 +65,7 @@ ROAD_POINTS = ClientHelper.RoadHardwareArt.generate_road_polygons(HEX_SIZE / 4,
 
 
 class card:
-    def __init__(self, location=[-100, -100], resource='Sheep'):
+    def __init__(self, location, resource='Sheep'):
         self.location = location
         self.resource = resource
 
@@ -77,8 +77,7 @@ class card:
 
 
 class card_animation:
-    def __init__(self, card_obj, callback, init, dest, steps, fps=30):
-        # print('animation created')
+    def __init__(self, card_obj, callback, init, dest, steps, delta_time):
         self.card = card_obj
 
         self.init = init
@@ -104,13 +103,17 @@ class card_animation:
         self.total_steps = steps
 
         self.location = init
-        try:
-            self.step_size_x = (self.dest[0] - self.init[0]) / steps / ((fps) / 30)
-            self.step_size_y = (self.dest[1] - self.init[1]) / steps / ((fps) / 30)
-        except ZeroDivisionError: 
-            self.step_size_x = (self.dest[0] - self.init[0]) / steps * 3
-            self.step_size_y = (self.dest[1] - self.init[1]) / steps * 3
 
+        assumed_frame_rate = 60
+        actual_frame_rate = 1 / delta_time
+
+        try:
+            self.step_size_x = (self.dest[0] - self.init[0]) / steps * (assumed_frame_rate / actual_frame_rate)
+            self.step_size_y = (self.dest[1] - self.init[1]) / steps * (assumed_frame_rate / actual_frame_rate)
+            self.total_steps *= (actual_frame_rate / assumed_frame_rate)
+        except ZeroDivisionError: 
+            self.step_size_x = (self.dest[0] - self.init[0]) / steps
+            self.step_size_y = (self.dest[1] - self.init[1]) / steps
 
         self.steps_done = 0
 
@@ -366,21 +369,21 @@ class Client:
         index = 0
         # print('MINE', list_cards)
 
-        time = self.clock.get_fps()
+        #time = self.clock.get_fps()
 
         for card_t in card_type:
             if list_cards[index] > 0:
                 card_lost = card(location_start, card_t)
                 for anything in range(0, list_cards[index]):
                     self.animations.append(
-                        card_animation(card_lost, None, location_start, location_end, location_steps, time))
+                        card_animation(card_lost, None, location_start, location_end, location_steps, self.time_delta))
                     cards_removed.append(card_lost.resource)
 
             if list_cards[index] < 0:
                 card_gained = card(location_start, card_t)
                 for anything in range(list_cards[index], 0):
                     self.animations.append(
-                        card_animation(card_gained, self.add_card, location_end, location_start, location_steps, time))
+                        card_animation(card_gained, self.add_card, location_end, location_start, location_steps, self.time_delta))
             index += 1
         self.remove_card(cards_removed)
         # self.card_keys = card_keys
@@ -950,7 +953,7 @@ class Client:
 
         self.manager = pg_g.UIManager(RESOLUTION, './themes/total_theme.json')
         self.manager.preload_fonts([{'name': 'fira_code', 'point_size': 14, 'style': 'bold'}])
-        self.clock = pygame.time.Clock()
+        #self.clock = pygame.time.Clock()
 
         # creates settlement polygon
         house_width = 120 * self.scale / 2
@@ -1415,8 +1418,9 @@ class Client:
         if self.text_dialog is not None:
             self.text_dialog.add_line(text)
 
-    def update_frame(self, time_delta):
-        #time_delta = self.clock.tick(30) / 1000.0
+    def update_frame(self, clock, time_delta):
+        self.time_delta = time_delta
+        self.clock = clock
         if self.board_updated:
             self.info_panel.set_bank_info(self.bank)
             self.info_panel.set_player_info(self.player, self.enemy_list, self.turn_player)
@@ -1579,8 +1583,10 @@ class Client:
             for butt in self.robber_butts:
                 butt.draw(graphics)
 
-        #text = str(self.clock.get_fps() // 1)
-        #text_surface = pygame.font.Font.render(self.font, text[:-2], True, (255, 255, 255), None)
-        #graphics.blit(text_surface, (0, 0))
+        '''
+        text = str(self.clock.get_fps() // 1)
+        text_surface = pygame.font.Font.render(self.font, text[:-2], True, (255, 255, 255), None)
+        graphics.blit(text_surface, (0, 0))
+        '''
 
         self.game_window.blit(graphics, (0, 0))
