@@ -155,7 +155,7 @@ class GameLobby:
                 self.player_left = False
             if self.state == "game":
                 try:
-                    self.client_instance.update_frame(time_delta)
+                    self.client_instance.update_frame(clock, time_delta)
                 except TypeError:
                     pass
                 if not self.client_instance.running and self.winner=='':
