@@ -3,8 +3,6 @@ import os
 import queue
 import random
 import threading
-from queue import Queue
-from typing import Any
 
 from aiohttp import web
 
@@ -125,7 +123,7 @@ class ServerThread:
                 continue
             msg = self.queue.get()
             self.queue.task_done()
-            print("test", msg)
+            #print("test", msg)
             return msg
 
         def get_key_from_color(color):
@@ -138,32 +136,6 @@ class ServerThread:
                 await sendtoall("quit")  # turn this into who won for the victory screen, obv
             game_over(self.code)
 
-        # print('Waitiing for a Connection..')
-        '''
-        res = readfromBuffer(Client)
-        name = res
-        print(name)
-        Client.send(str.encode("host\n"))
-        clients.append(client(name, address, Client, Colors[0]))
-        Colors.pop(0)
-        #numplayers = readfromBuffer(Client)
-        #print(int(numplayers))
-        for x in range(int(numplayers) - 1):
-            Client, address = ServerSocket.accept()
-            res = readfromBuffer(Client)
-            name = res
-            print(name)
-            # for cli in clients:
-            #    i =0
-            #    cli.socket.send(str.encode(name+" connected\n"))
-            clients.append(client(name, address, Client, Colors[0]))
-            Colors.pop(0)
-        
-        for i in range(0, len(clients)):
-            sendstring = "color,"
-            sendstring = sendstring + clients[i].color+','+str(i) + '\n'
-            clients[i].socket.send(str.encode(sendstring))
-        '''
         # board randomizer
 
         numberstring = 'board|' + ','.join([str(elem) for elem in self.number_list]) + '|' + ','.join(
@@ -184,10 +156,11 @@ class ServerThread:
 
         random.shuffle(keyorder)
         for key in keyorder:
+            await sendtoall('turnorder,'+self.players[key].color)
             await sendtoOne("set", key)
-            print("test")
+            # print("test")
             coordinates = readfromBuffer()
-            print(coordinates)
+            # print(coordinates)
             if coordinates == "quit":
                 await quit()
                 return
@@ -210,6 +183,7 @@ class ServerThread:
             await sendtoallButOne(message, key)
 
         for key in reversed(keyorder):
+            await sendtoall('turnorder,'+self.players[key].color)
             await sendtoOne("set", key)
             coordinates = readfromBuffer()
             if coordinates == "quit":
@@ -247,7 +221,10 @@ class ServerThread:
             await sendtoallButOne(message, key)
         while not self.winner:
             for key in keyorder:
+                await sendtoall('turnorder,'+self.players[key].color)
                 dice = dice_roll()
+                for key2 in keyorder:
+                    await sendtoOne('diceroll,' + dice, key2)
                 if int(dice.split(',')[0]) + int(dice.split(',')[1]) == 7:
                     await sendtoall('dice,' + dice)
                     await sendtoall('discard')
@@ -264,10 +241,10 @@ class ServerThread:
                             await sendtoallButOne(res[1], key4)
                             await sendtoallButOne(res[2], key4)
                 else:
-                    # await sendtoall('dice,' + dice)
+                    # await sendtoall('diceroll,' + dice)
                     for key2 in keyorder:
                         await sendtoOne('dice,' + dice, key2)
-                        print('dice,' + dice, key2)
+                        # print('dice,' + dice, key2)
                         message = readfromBuffer()
                         if message == "quit":
                             await quit()
@@ -287,7 +264,7 @@ class ServerThread:
                     if message == "quit":
                         await quit()
                         return
-                    # print(message)
+                    # #print(message)
                     if message == "end":
                         message = readfromBuffer()
                         if message == "quit":
@@ -297,7 +274,8 @@ class ServerThread:
                         break
                     elif message.split(',')[0] == "winner":
                         self.winner = True
-                        # print(message)
+                        await sendtoall(message)
+                        # #print(message)
                         break
                     elif message.split('|')[0] == "tradeoffer":
                         await sendtoallButOne(message, key)
@@ -354,7 +332,7 @@ class ServerThread:
                         await sendtoallButOne(message, key)
                 await sendtoOne("notturn", key)
                 # message=readfromBuffer(cli.socket)
-                # print(message)
+                # #print(message)
                 # await sendtoallButOne(message, cli)
 
         # game loop
@@ -365,7 +343,7 @@ class ServerThread:
     '''
     except(ConnectionResetError):
         {
-            print("A player has disconnected")
+            #print("A player has disconnected")
         }
     '''
 
@@ -404,6 +382,11 @@ async def make_game(request):
             running_games[game_code].players[player_code].screen_num))
 
 
+async def get_from_queue(code, player_code):
+    msg = await running_games[code].players[player_code].queue.get()
+    return msg
+
+
 async def get_data(request):
     code = request.match_info.get('game_id', "fail")
     if code == "fail" or code not in running_games.keys():
@@ -411,13 +394,19 @@ async def get_data(request):
     player_code = request.match_info.get('player_id', "fail")
     if player_code == "fail" or player_code not in running_games[code].players.keys():
         return web.Response(text="player not found")
-    msg = await running_games[code].players[player_code].queue.get()
+    try:
+        msg = await asyncio.wait_for(get_from_queue(code, player_code), timeout=10.0)
+    except asyncio.TimeoutError:
+        return web.Response(text='t')
     return web.Response(text=msg)
+
+
 async def kill_all_games(request):
     data = await request.post()
-    if data['code']=='double_snap':
-        for key in running_games.keys():
-            game_over(key)
+    if data['code'] == 'double_snap':
+        running_games.clear()
+
+
 async def game_update(request):
     data = await request.post()
     code = request.match_info.get('game_id', "fail")
@@ -427,10 +416,10 @@ async def game_update(request):
     if player_code == "fail" or player_code not in running_games[code].players.keys():
         return web.Response(text="player not found")
     #
-    print('data is', data['msg'])
+    # print('data is', data['msg'])
     if data['msg'] == "start":
         if running_games[code].players[player_code].is_host and not running_games[code].started:
-            print('send:', data['msg'])
+            # print('send:', data['msg'])
             threading.Thread(target=running_games[code].run, ).start()
             running_games[code].started = True
         else:
@@ -453,10 +442,10 @@ async def game_update(request):
             asyncio.run_coroutine_threadsafe(running_games[code].players[player_code].queue.put("quit"), loop)
             del running_games[code].players[player_code]
             running_games[code].color_list.append(color)
-            print(running_games[code].players.keys())
+            # print(running_games[code].players.keys())
     elif data['msg'] == "quit":
-        for key in running_games[code].players.keys():
-            asyncio.run_coroutine_threadsafe(running_games[code].players[key].queue.put("quit"), loop)
+        #for key in running_games[code].players.keys():
+            #asyncio.run_coroutine_threadsafe(running_games[code].players[key].queue.put("quit"), loop)
         running_games[code].handle_incoming(data['msg'])
 
     else:
@@ -471,7 +460,7 @@ def main():
     app.router.add_route('POST', '/join/{game_id}', join)
     app.router.add_route('GET', '/{game_id}/{player_id}/get', get_data)
     app.router.add_route('POST', '/{game_id}/{player_id}/post', game_update)
-    app.router.add_route('POST','/killgames', kill_all_games)
+    app.router.add_route('POST', '/killgames', kill_all_games)
     f = loop.create_server(app.make_handler(), '0.0.0.0', os.environ.get('PORT', '5000'))
     srv = loop.run_until_complete(f)
     print('serving on', srv.sockets[0].getsockname())
